==> layerborn.cdk-ami-builder-0.0.2.tar.gz: layerborn.cdk-ami-builder-0.0.2/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "layerborn.cdk-ami-builder",
    "version": "0.0.2",
    "description": "Creates an EC2 AMI using an Image Builder Pipeline and returns the AMI ID.",
    "license": "Apache-2.0",
    "url": "https://github.com/layerborn/cdk-ami-builder-construct.git",
    "long_description_content_type": "text/markdown",
    "author": "Jayson Rawlins<jayson.rawlins@layerborn.io>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/layerborn/cdk-ami-builder-construct.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "layerborn.cdk_ami_builder",
        "layerborn.cdk_ami_builder._jsii"
    ],
    "package_data": {
        "layerborn.cdk_ami_builder._jsii": [
            "cdk-ami-builder@0.0.2.jsii.tgz"
        ],
        "layerborn.cdk_ami_builder": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.8",
    "install_requires": [
        "aws-cdk-lib>=2.100.0, <3.0.0",
        "constructs>=10.1.203, <11.0.0",
        "jsii>=1.94.0, <2.0.0",
        "layerborn.cdk-iam-policy-builder-helper<0.0.1",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> layerborn.cdk-ami-builder-0.0.3.tar.gz: layerborn.cdk-ami-builder-0.0.3/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "layerborn.cdk-ami-builder",
    "version": "0.0.3",
    "description": "Creates an EC2 AMI using an Image Builder Pipeline and returns the AMI ID.",
    "license": "Apache-2.0",
    "url": "https://github.com/layerborn/cdk-ami-builder-construct.git",
    "long_description_content_type": "text/markdown",
    "author": "Jayson Rawlins<jayson.rawlins@layerborn.io>",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/layerborn/cdk-ami-builder-construct.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "layerborn.cdk_ami_builder",
        "layerborn.cdk_ami_builder._jsii"
    ],
    "package_data": {
        "layerborn.cdk_ami_builder._jsii": [
            "cdk-ami-builder@0.0.3.jsii.tgz"
        ],
        "layerborn.cdk_ami_builder": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.8",
    "install_requires": [
        "aws-cdk-lib>=2.100.0, <3.0.0",
        "constructs>=10.1.203, <11.0.0",
        "jsii>=1.94.0, <2.0.0",
        "layerborn.cdk-iam-policy-builder-helper>=0.0.1, <0.0.2",
        "publication>=0.0.3",
        "typeguard~=2.13.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
